@@ -1,6 +1,8 @@
 sub Mojo::Webqq::Client::_recv_message{
     my $self = shift;
     return if $self->is_stop;
+    return if $self->is_polling;
+    $self->is_polling(1);
     my $api_url = ($self->security?'https':'http') . '://d1.web2.qq.com/channel/poll2';
     my $callback = sub {
         my ($json,$ua,$tx) = @_;
@@ -12,6 +14,7 @@ sub Mojo::Webqq::Client::_recv_message{
             }
         };
         $self->error($@) if $@;
+        $self->is_polling(0);
         #重新开始接收消息
         $self->emit("poll_over");
     };
@@ -23,12 +26,12 @@ sub Mojo::Webqq::Client::_recv_message{
         key         =>  "",
     );
     my $headers = {Referer=>"http://d1.web2.qq.com/proxy.html?v=20151105001&callback=1&id=2",json=>1};
-    $self->http_post(
+    my $id = $self->http_post(
         $api_url,   
         $headers,
         form=>{r=>$self->encode_json(\%r)},
         $callback
     );
-     
+    $self->poll_connection_id($id);
 }
 1;
