@@ -3,7 +3,7 @@ $Mojo::Webqq::Plugin::FuckDaShen::PRIORITY = 1;
 
 my @reply = (
     "动不动就叫%...",
-    "%你妹啊，能不能换点别的称呼...",
+    "%能不能换点别的称呼...",
     "%，%，%，%..喜欢你就叫个够...",
     "请问%是指哪位?",
     "能不能别随随便便就叫%?"
